"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadTelefuncFilesFromConfig = void 0;
const utils_1 = require("../../utils");
const path_1 = require("path");
const import_1 = require("@brillout/import");
async function loadTelefuncFilesFromConfig(runContext) {
    const { appRootDir } = runContext;
    (0, utils_1.assertUsage)(appRootDir, 'You need to set `config.root` to be able to use `config.telefuncFiles`');
    (0, utils_1.assertPosixPath)(appRootDir);
    const telefuncFilesLoaded = {};
    const telefuncFilesAll = [];
    await Promise.all(runContext.telefuncFilesManuallyProvidedByUser.map(async (telefuncFilePathAbsolute) => {
        const telefuncFilePath = resolveTelefuncFilePath(telefuncFilePathAbsolute, appRootDir);
        telefuncFilesAll.push(telefuncFilePath);
        (0, utils_1.assert)((0, utils_1.isTelefuncFilePath)(runContext.telefuncFilePath));
        (0, utils_1.assert)((0, utils_1.isTelefuncFilePath)(telefuncFilePath));
        if (telefuncFilePath !== runContext.telefuncFilePath) {
            return;
        }
        const telefunctions = await (0, import_1.import_)(telefuncFilePathAbsolute);
        telefuncFilesLoaded[telefuncFilePath] = telefunctions;
    }));
    return { telefuncFilesLoaded, telefuncFilesAll };
}
exports.loadTelefuncFilesFromConfig = loadTelefuncFilesFromConfig;
function resolveTelefuncFilePath(telefuncFilePathAbsolute, appRootDir) {
    (0, utils_1.assertPosixPath)(telefuncFilePathAbsolute);
    const path = path_1.posix.relative(appRootDir, telefuncFilePathAbsolute);
    (0, utils_1.assertPosixPath)(path);
    (0, utils_1.assertUsage)(!path.startsWith('../'), `Your telefunc file \`${telefuncFilePathAbsolute}\` is not inlcuded in your project root \`${appRootDir}\`.`);
    (0, utils_1.assert)(!path.startsWith('/') && !path.startsWith('.'));
    const telefuncFilePath = '/' + path;
    (0, utils_1.assert)((0, utils_1.isTelefuncFilePath)(telefuncFilePathAbsolute));
    return telefuncFilePath;
}
